==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/css.prep/src/org/netbeans/modules/css/prep/problems/SassProjectProblemsProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.css.prep.problems;

import java.util.Collection;
import org.netbeans.api.project.Project;
import org.netbeans.modules.css.prep.CssPreprocessorType;
import org.netbeans.modules.css.prep.preferences.SassPreferences;
import org.netbeans.modules.css.prep.preferences.SassPreferencesValidator;
import org.netbeans.modules.css.prep.sass.SassExecutable;
import org.netbeans.modules.css.prep.util.InvalidExternalExecutableException;
import org.netbeans.modules.css.prep.util.ValidationResult;
import org.openide.util.NbBundle;

public final class SassProjectProblemsProvider extends BaseProjectProblemsProvider {

    public SassProjectProblemsProvider(Project project) {
        super(project);
    }

    @NbBundle.Messages("SassProjectProblemsProvider.displayName=Sass")
    @Override
    String getDisplayName() {
        return Bundle.SassProjectProblemsProvider_displayName();
    }
    @Override
    boolean isEnabled(Project project) {
        return SassPreferences.getInstance().isEnabled(project);
    }

    @Override
    CssPreprocessorType getFileType() {
        return CssPreprocessorType.SASS;
    }

    @NbBundle.Messages({
        "SassProjectProblemsProvider.invalidCompiler.title=Invalid Sass compiler",
        "SassProjectProblemsProvider.invalidCompiler.description=The provided Sass compiler is not valid.",
    })
    @Override
    void checkCompiler(Collection<ProjectProblem> currentProblems) {
        try {
            SassExecutable.getDefault();
        } catch (InvalidExternalExecutableException ex) {
            ProjectProblem problem = ProjectProblem.createError(
                    Bundle.SassProjectProblemsProvider_invalidCompiler_title(),
                    Bundle.SassProjectProblemsProvider_invalidCompiler_description(),
                    OPTIONS_PROBLEM_RESOLVER);
            currentProblems.add(problem);
        }
    }

    @Override
    ValidationResult validatePreferences(Project project) {
        return new SassPreferencesValidator()
                .validate(project)
                .getResult();
    }

}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/css.prep/src/org/netbeans/modules/css/prep/problems/SassProjectProblemsProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.css.prep.problems;

import java.util.Collection;
import org.netbeans.api.project.Project;
import org.netbeans.modules.css.prep.CssPreprocessorType;
import org.netbeans.modules.css.prep.preferences.SassPreferences;
import org.netbeans.modules.css.prep.preferences.SassPreferencesValidator;
import org.netbeans.modules.css.prep.sass.SassCli;
import org.netbeans.modules.css.prep.util.InvalidExternalExecutableException;
import org.netbeans.modules.web.common.api.ValidationResult;
import org.openide.util.NbBundle;

public final class SassProjectProblemsProvider extends BaseProjectProblemsProvider {

    public SassProjectProblemsProvider(Project project) {
        super(project);
    }

    @NbBundle.Messages("SassProjectProblemsProvider.displayName=Sass")
    @Override
    String getDisplayName() {
        return Bundle.SassProjectProblemsProvider_displayName();
    }
    @Override
    boolean isEnabled(Project project) {
        return SassPreferences.getInstance().isEnabled(project);
    }

    @Override
    CssPreprocessorType getFileType() {
        return CssPreprocessorType.SASS;
    }

    @NbBundle.Messages({
        "SassProjectProblemsProvider.invalidCompiler.title=Invalid Sass compiler",
        "SassProjectProblemsProvider.invalidCompiler.description=The provided Sass compiler is not valid.",
    })
    @Override
    void checkCompiler(Collection<ProjectProblem> currentProblems) {
        try {
            SassCli.getDefault();
        } catch (InvalidExternalExecutableException ex) {
            ProjectProblem problem = ProjectProblem.createError(
                    Bundle.SassProjectProblemsProvider_invalidCompiler_title(),
                    Bundle.SassProjectProblemsProvider_invalidCompiler_description(),
                    OPTIONS_PROBLEM_RESOLVER);
            currentProblems.add(problem);
        }
    }

    @Override
    ValidationResult validatePreferences(Project project) {
        return new SassPreferencesValidator()
                .validate(project)
                .getResult();
    }

}
